summaryrefslogtreecommitdiffhomepage
path: root/dev/ZKA/Sources/ProcessTeam.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'dev/ZKA/Sources/ProcessTeam.cxx')
-rw-r--r--dev/ZKA/Sources/ProcessTeam.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/dev/ZKA/Sources/ProcessTeam.cxx b/dev/ZKA/Sources/ProcessTeam.cxx
index 58a639f6..f7282faf 100644
--- a/dev/ZKA/Sources/ProcessTeam.cxx
+++ b/dev/ZKA/Sources/ProcessTeam.cxx
@@ -6,16 +6,16 @@
/***********************************************************************************/
/// @file ProcessTeam.cxx
/// @brief Process teams implementation.
/***********************************************************************************/
-#include <KernelKit/ProcessScheduler.hxx>
+#include <KernelKit/UserProcessScheduler.hxx>
namespace Kernel
{
/// @brief Process list array getter.
/// @return The list of process to schedule.
- Array<PROCESS_HEADER_BLOCK, kSchedProcessLimitPerTeam>& ProcessTeam::AsArray()
+ Array<UserProcess, kSchedProcessLimitPerTeam>& ProcessTeam::AsArray()
{
return mProcessList;
}
@@ -29,7 +29,7 @@ namespace Kernel
/// @brief Current process getter.
/// @return The current process header.
- Ref<PROCESS_HEADER_BLOCK>& ProcessTeam::AsRef()
+ Ref<UserProcess>& ProcessTeam::AsRef()
{
return mCurrentProcess;
}
@@ -6,16 +6,16 @@
/***********************************************************************************/
/// @file ProcessTeam.cxx
-/// @brief Process teams implementation.
+/// @brief UserProcess teams implementation.
/***********************************************************************************/
@@ -6,16 +6,16 @@
namespace Kernel
{
- /// @brief Process list array getter.
+ /// @brief UserProcess list array getter.
/// @return The list of process to schedule.